@@ -33,7 +33,7 @@ to print the name of each directory as it is created
 =item *
 
 the numeric mode to use when creating the directories
-(defaults to 0777)
+(defaults to 0777), to be modified by the current umask.
 
 =back
 
@@ -110,7 +110,7 @@ use strict;
 use warnings;
 use Cwd 'getcwd';
 
-our $VERSION = "1.06";
+our $VERSION = "1.07";
 our @ISA = qw( Exporter );
 our @EXPORT = qw( mkpath rmtree );
 
